<?php
// Start session to ensure user is logged in
session_start();
if (empty($_SESSION['custusername'])) {
    header("Location: login_form.php");
    exit();
}

// Include the database connection
require_once 'mysqli_connect.php'; // Ensure this is the correct path

// Check for successful connection
if (!$dbc) {
    die("Database connection failed: " . mysqli_connect_error());
}

// Collect search form inputs
$item_no = isset($_POST['item_no']) ? $_POST['item_no'] : '';
$product_name = isset($_POST['product_name']) ? $_POST['product_name'] : '';
$product_type = isset($_POST['product_type']) ? $_POST['product_type'] : '';
$release_year = isset($_POST['release_year']) ? $_POST['release_year'] : '';
$pieces_min = isset($_POST['pieces_min']) ? $_POST['pieces_min'] : 0;
$pieces_max = isset($_POST['pieces_max']) ? $_POST['pieces_max'] : 15000;
$price_min = isset($_POST['price_min']) ? $_POST['price_min'] : 0.01;
$price_max = isset($_POST['price_max']) ? $_POST['price_max'] : 10000.00;

// Start building the SQL query
$query = "SELECT * FROM product WHERE 1"; // Default condition is always true

// Add conditions based on user input
if (!empty($item_no)) {
    $item_no = mysqli_real_escape_string($dbc, $item_no);
    $query .= " AND item_no = '$item_no'";
}
if (!empty($product_name)) {
    $product_name = mysqli_real_escape_string($dbc, $product_name);
    $query .= " AND product_name LIKE '%$product_name%'";
}
if (!empty($product_type)) {
    $product_type = mysqli_real_escape_string($dbc, $product_type);
    $query .= " AND product_type = '$product_type'";
}
if (!empty($release_year)) {
    $release_year = mysqli_real_escape_string($dbc, $release_year);
    $query .= " AND release_year = '$release_year'";
}
if (!empty($pieces_min) || !empty($pieces_max)) {
    $pieces_min = (int)$pieces_min;
    $pieces_max = (int)$pieces_max;
    $query .= " AND number_pieces BETWEEN $pieces_min AND $pieces_max";
}
if (!empty($price_min) || !empty($price_max)) {
    $price_min = (float)$price_min;
    $price_max = (float)$price_max;
    $query .= " AND price BETWEEN $price_min AND $price_max";
}

// Execute the query
$result = mysqli_query($dbc, $query);

// Check if any rows are returned
if ($result && mysqli_num_rows($result) > 0) {
    echo "<h2>Search Results</h2>";
    while ($row = mysqli_fetch_assoc($result)) {
        $item_no = htmlspecialchars($row['item_no']);
        $product_name = htmlspecialchars($row['product_name']);
        $product_type = htmlspecialchars($row['product_type']);
        $release_year = htmlspecialchars($row['release_year']);
        $price = htmlspecialchars($row['price']);
        $number_pieces = htmlspecialchars($row['number_pieces']);

        // Resolve the image URL directly from the database
        $image_url = htmlspecialchars($row['image_url']);

        // Fallback to placeholder if image URL is missing or invalid
        if (empty($image_url) || !filter_var($image_url, FILTER_VALIDATE_URL)) {
            $image_url = 'images/placeholder.jpg'; // Local placeholder in the same directory
        }

        // Display the product details
        echo "<div class='product'>";
        echo "<h3>$product_name ($item_no)</h3>";
        echo "<p><strong>Type:</strong> $product_type</p>";
        echo "<p><strong>Release Year:</strong> $release_year</p>";
        echo "<p><strong>Price:</strong> \$$price</p>";
        echo "<p><strong>Number of Pieces:</strong> $number_pieces</p>";
        echo "<img src='$image_url' alt='$product_name' style='width: 200px; height: auto;'>";
        echo "</div>";
    }
} else {
    echo "<p>No products found matching your search criteria.</p>";
}

// Close the database connection
mysqli_close($dbc);
?>

